# Credit

These sounds were created by Tim Kahn and hosted on freesound.org
 - Tim Kahn ( https://freesound.org/people/tim.kahn/ )

Thank you Amy Gedgaudas and Tim Kahn for all these sounds.

# License

Attribution: http://creativecommons.org/licenses/by/3.0/

# Packs

All of the sounds except capital.wav come from these two packs:
  - [Phonetic Alphabet](https://freesound.org/people/tim.kahn/packs/14153/)
  - [Roulette](https://freesound.org/people/tim.kahn/packs/5799)

# Sounds


### Alphabet
  - alpha.wav
    - url: https://freesound.org/s/223905/
  - bravo.wav
    - url: https://freesound.org/s/223904/
  - charlie.wav
    - url: https://freesound.org/s/223903/
  - delta.wav
    - url: https://freesound.org/s/223902/
  - echo.wav
    - url: https://freesound.org/s/223909/
  - foxtrot.wav
    - url: https://freesound.org/s/223908/
  - golf.wav
    - url: https://freesound.org/s/223907/
  - hotel.wav
    - url: https://freesound.org/s/223906/
  - india.wav
    - url: https://freesound.org/s/223911/
  - juliet.wav
    - url: https://freesound.org/s/223910/
  - kilo.wav
    - url: https://freesound.org/s/223921/
  - lima.wav
    - url: https://freesound.org/s/223920/
  - mike.wav
    - url: https://freesound.org/s/223919/
  - november.wav
    - url: https://freesound.org/s/223918/
  - oscar.wav
    - url: https://freesound.org/s/223925/
  - papa.wav
    - url: https://freesound.org/s/223924/
  - quebec.wav
    - url: https://freesound.org/s/223923/
  - romeo.wav
    - url: https://freesound.org/s/223922/
  - sierra.wav
    - url: https://freesound.org/s/223927/
  - tango.wav
    - url: https://freesound.org/s/223926/
  - uniform.wav
    - url: https://freesound.org/s/223914/
  - victor.wav
    - url: https://freesound.org/s/223915/
  - whiskey.wav
    - url: https://freesound.org/s/223912/
  - x-ray.wav
    - url: https://freesound.org/s/223913/
  - yankee.wav
    - url: https://freesound.org/s/223916/
  - zulu.wav
    - url: https://freesound.org/s/223917/


### Digits
  - 0.wav
    - url: https://freesound.org/s/89296/
  - 1.wav
    - url: https://freesound.org/s/89297/
  - 2.wav
    - url: https://freesound.org/s/89308/
  - 3.wav
    - url: https://freesound.org/s/89319/
  - 4.wav
    - url: https://freesound.org/s/89327/
  - 5.wav
    - url: https://freesound.org/s/89328/
  - 6.wav
    - url: https://freesound.org/s/89329/
  - 7.wav
    - url: https://freesound.org/s/89330/
  - 8.wav
    - url: https://freesound.org/s/89331/
  - 9.wav
    - url: https://freesound.org/s/89332/


### Others
  - capital.wav
      - url: https://freesound.org/s/110650/
